summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoVariable.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoVariable.cpp')
-rw-r--r--lib/kotext/KoVariable.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/kotext/KoVariable.cpp b/lib/kotext/KoVariable.cpp
index 8ee25c19..856c05f1 100644
--- a/lib/kotext/KoVariable.cpp
+++ b/lib/kotext/KoVariable.cpp
@@ -569,10 +569,10 @@ void KoVariableCollection::setVariableSelected(KoVariable * var)
m_varSelected=var;
}
-// TODO change to TQValueList<KAction *>, but only once plugActionList takes that
-TQPtrList<KAction> KoVariableCollection::popupActionList() const
+// TODO change to TQValueList<TDEAction *>, but only once plugActionList takes that
+TQPtrList<TDEAction> KoVariableCollection::popupActionList() const
{
- TQPtrList<KAction> listAction;
+ TQPtrList<TDEAction> listAction;
// Insert list of actions that change the subtype
const TQStringList subTypeList = m_varSelected->subTypeList();
kdDebug() << k_funcinfo << "current subtype=" << m_varSelected->subType() << endl;
@@ -583,7 +583,7 @@ TQPtrList<KAction> KoVariableCollection::popupActionList() const
{
// We store the subtype number as the action name
TQCString name; name.setNum(i);
- KToggleAction * act = new KToggleAction( *it, KShortcut(), 0, name );
+ TDEToggleAction * act = new TDEToggleAction( *it, TDEShortcut(), 0, name );
connect( act, TQT_SIGNAL(activated()), this, TQT_SLOT(slotChangeSubType()) );
if ( i == m_varSelected->subType() )
act->setChecked( true );
@@ -600,14 +600,14 @@ TQPtrList<KAction> KoVariableCollection::popupActionList() const
for ( int i = 0; it != list.end() ; ++it, ++i )
{
if( i == 0 ) // first item, and list not empty
- listAction.append( new KActionSeparator() );
+ listAction.append( new TDEActionSeparator() );
if ( !(*it).isEmpty() ) // in case of removed subtypes or placeholders
{
format->setFormatProperties( *it ); // temporary change
TQString text = format->convert( m_varSelected->varValue() );
// We store the raw format as the action name
- KToggleAction * act = new KToggleAction(text, KShortcut(), 0, (*it).utf8());
+ TDEToggleAction * act = new TDEToggleAction(text, TDEShortcut(), 0, (*it).utf8());
connect( act, TQT_SIGNAL(activated()), this, TQT_SLOT(slotChangeFormat()) );
if ( (*it) == currentFormat )
act->setChecked( true );
@@ -622,7 +622,7 @@ TQPtrList<KAction> KoVariableCollection::popupActionList() const
void KoVariableCollection::slotChangeSubType()
{
- KAction * act = (KAction *)(sender());
+ TDEAction * act = (TDEAction *)(sender());
int menuNumber = TQCString(act->name()).toInt();
int newSubType = m_varSelected->variableSubType(menuNumber);
kdDebug(32500) << "slotChangeSubType: menuNumber=" << menuNumber << " newSubType=" << newSubType << endl;
@@ -637,7 +637,7 @@ void KoVariableCollection::slotChangeSubType()
void KoVariableCollection::slotChangeFormat()
{
- KAction * act = (KAction *)(sender());
+ TDEAction * act = (TDEAction *)(sender());
TQString newFormat = TQString::fromUtf8(act->name());
TQString oldFormat = m_varSelected->variableFormat()->formatProperties();
if (oldFormat != newFormat )